package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`"``!````X!P```````!``````````)`'`0``
M````!P``@$``.``*`$``'@`=``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0````PI0``````
M`#"E````````,*4````````/``````````\``````````0`````````#``!P
M!````'`"````````<`(```````!P`@```````!@`````````&``````````(
M``````````$````%````````````````````````````````````1*4`````
M``!$I0```````````0```````0````8```#P_P```````/#_`0``````\/\!
M```````P`P```````&`#```````````!```````"````!````&`$````````
M8`0```````!@!````````&`"````````8`(````````(``````````0````$
M````&`0````````8!````````!@$````````1`````````!$``````````0`
M````````4>5T9`<`````````````````````````````````````````````
M````````````$`````````!2Y71D!````/#_````````\/\!``````#P_P$`
M`````!``````````$``````````!````````````````````````````````
M``````````````````````````````````````````@```````````!``@("
M``$```````````$``````````2@```````#V!P"R````````````````````
M```````P@`(```````$H````````````````````````````````````````
M,(`"```````!*````````````````````````````````````````#"``@``
M`````2@````````$``"R```````````````````````````P@`(```````$H
M````````/``!L@``````````````````````````,(`"```````!*```````
M`/P/__(``````````````````````````#"``@```````2@```````#\_W^S
M```````````````````````````P@`(```````$H````````A```L@``````
M````````````````````,(`"```````!*```````````````````````````
M`````````````#"``@```````2@```````````"P````````````````````
M```````P@`(```````0````4`````P```$=.50"`I0(@U\SU1'%2E<E:GZ&Z
M,F,@Q00````0`````0```$=.50```````P````(```````````````$`````
M````%@,````````!`````````"8#`````````0`````````P`P````````P`
M`````````!H````````-`````````$!C````````&0````````#P_P$`````
M`!L`````````"``````````:`````````/C_`0``````'``````````(````
M``````0`````````P`8````````%`````````'@3````````!@````````#H
M"0````````H`````````N00````````+`````````!@`````````-0``<```
M``#P^@$``````!4````````````````````#`````````$```@``````$0``
M``````"@&0```````!(`````````8``````````3`````````!``````````
M`0``<``````!``````````4``'```````@`````````&``!P````````````
M````"@``<``````7`````````!$``'``````9@`````````2``!P`````!T`
M````````$P``<``````C`````````!X`````````&`````````#[__]O````
M``$```@`````_O__;P``````&0```````/___V\``````@````````#P__]O
M`````#(8````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````80```&8``````````````!$````K````````
M``````!A```````````````6````+@`````````C````9````!@`````````
M.0```"(````$````2@```!T````)````8P```#\``````````````$$````E
M````)@``````````````!P```"0````0```````````````A````1P``````
M``!@`````````$\`````````4P```"`````<````,P````````!%````$P``
M`#(```!;````,0``````````````$@```#4````L````)P``````````````
M```````````I``````````,``````````````%`````Z`````````#@```!"
M````/````````````````````%(````O````&P```!\````P````-@``````
M```M````%P```````````````````!4`````````*`````@````J````3```
M`$,```!E````````````````````````````````````````````````````
M```````````*``````````````!5````5`````X`````````````````````
M````````````````````#P```#X`````````0````!H`````````/0```#0`
M````````!@``````````````'@```!D```!8````-P````````!-````````
M``````!<````7@`````````-````%```````````````.P````````!=````
M2````&(```!&`````````%<`````````3@````````!$````60``````````
M````"P```$D````,```````````````"`````````$L```!?````````````
M``!1``````````````````````````4``````````````%8```!:````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````#
M``P``!H``````````````````"P$```@`!4````"`````````````````-T#
M```0`!D`(`,"`````````````````.,#```2``T`0"@````````8````````
M`/0#```2``T`$"L```````!4``````````$````3`/'_`0``````````````
M`````#@#```2``T`2#\```````#4`@````````$$```2``T`D#(```````"X
M`````````$X#```2``T`0"<``````````0```````+L#```2``T`:"L`````
M```\`0```````)<#```2``T`P%P```````"H`@````````\$```2``T`2#,`
M``````!(`````````-$#```2``T`($(```````!T`0```````,H"```1`!``
M<&,````````$`````````"H$```0`!4````"`````````````````&8````6
M`````````````````````````(P#```2``T`V%H```````#H`0```````#<$
M```2``T`Z"8```````!4`````````#\$```2``T`X!P`````````````````
M`$<$```0`!4````"`````````````````$X$```0`!D`(`,"````````````
M`````.D"```A`````````````````````````%H$```0``T`0!H`````````
M`````````(,#```2``T`4%H```````"(`````````&$$```0`!D`4`,"````
M`````````````!(````1`!8`,``"`````````````````.@"```1````````
M`````````````````*X#```2``T`^#0```````!,"@```````&8$```0`!@`
M(`,"`````````````````'$#```2``T`D#,```````!D`0```````&0#```2
M``T`6"@```````"T`@```````,<#```1`!4`(``"```````(`````````*$#
M```2``T`J"P```````#D!0```````-`!```2``T`0!H```````"<`@``````
M`*$!```2````(&,``````````````````+("```2````$&,`````````````
M`````,,!```2`````&,``````````````````),"```2````\&(`````````
M`````````+<````2````X&(``````````````````,8````2````T&(`````
M`````````````-$````1`````````````````````````!@"```2````P&(`
M`````````````````.D!```2````L&(``````````````````(P"```2````
MH&(``````````````````#\"```2````D&(``````````````````-X````2
M````@&(``````````````````/$````2````<&(``````````````````*8!
M```2````8&(``````````````````"\"```2````4&(`````````````````
M`&`"```2````0&(``````````````````!\"```2````,&(`````````````
M`````+T!```2````(&(```````````````````<"```2````$&(`````````
M``````````8!```2`````&(``````````````````.H````2````\&$`````
M`````````````-4!```2````X&$``````````````````*D````2````T&$`
M`````````````````-P!```2````P&$``````````````````"8"```2````
ML&$``````````````````.H"```1`````````````````````````)H"```2
M````H&$```````````````````0#```1`````````````````````````!(!
M```2````D&$``````````````````"$$```2````@&$`````````````````
M`/D!```2````<&$``````````````````*$"```2````8&$`````````````
M```````"```2````4&$``````````````````-D"```1````````````````
M`````````*X!```B`````````````````````````*@"```2````0&$`````
M`````````````)H````2````,&$``````````````````"$!```2````(&$`
M`````````````````(D````2`````````````````````````'D````2````
M`````````````````````%@````2````$&$``````````````````'`"```2
M`````&$``````````````````&$"```2````\&```````````````````#(!
M```@`````````````````````````'X"```2````X&``````````````````
M`"$````2````T&```````````````````$T````2````P&``````````````
M`````$P!```@`````````````````````````$T"```2````L&``````````
M`````````/$!```2````H&```````````````````&@!```2````D&``````
M`````````````#@"```2````@&```````````````````'8!```2````<&``
M`````````````````$0````2````8&```````````````````&@"```2````
M4&```````````````````/("```2````0&```````````````````.(!```2
M````,&```````````````````.`"```2````(&```````````````````(8!
M```B`````````````````````````#$````2````````````````````````
M`%("```2````$&```````````````````"8````2`````&``````````````
M`````)4!```2````\%\``````````````````!P````2````X%\`````````
M`````````'@"```2````T%\``````````````````(4"```2````P%\`````
M`````````````+D"```2````L%\```````````````````!?1%E.04U)0U],
M24Y+24Y'`%]?4DQ$7TU!4`!P97)L7V9R964`<&5R;%]P87)S90!097)L7V%T
M9F]R:U]U;FQO8VL`<&5R;%]R=6X`<&5R;%]A;&QO8P!097)L7W-Y<U]T97)M
M`%!,7V-U<G)E;G1?8V]N=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]A=&9O
M<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!P97)L7V1E<W1R=6-T`%!E<FQ?<WES
M7VEN:70S`%!E<FQ?;F5W6%,`4$Q?9&]?=6YD=6UP`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-V
M7W-E='!V;@!097)L7VYE=UA37V9L86=S`%])5$U?<F5G:7-T97)434-L;VYE
M5&%B;&4`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<W9?<V5T
M<'8`4&5R;%]G=E]F971C:'!V`%]?9VUO;E]S=&%R=%]?`%!E<FQ?9V5T7W-V
M`&5X:70`;65M;6]V90!?7V-X85]F:6YA;&EZ90!R;61I<@!?7VQI8F-?<W1A
M<G1?;6%I;@!S=')S='(`8VQO<V4`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!U
M;FQI;FL`;65M8W!Y`%]?<W1A8VM?8VAK7V9A:6P`;W!E;C8T`'-T<G1O:P!C
M;&]S961I<@!R96%D;&EN:P!M96US970`7U]S<')I;G1F7V-H:P!R96%D`%]?
M9G!R:6YT9E]C:&L`;'-T870V-`!L<V5E:S8T`&]P96YD:7(`;6MD:7(`86-C
M97-S`&=E='!I9`!M96UC:'(`<W1R9'5P`&=E='5I9`!S=')L96X`<F5A9&1I
M<C8T`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`%])3U]S=&1I;E]U<V5D`'-T
M9&5R<@!R96%L;&]C`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T
M86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S8`;&EB8RYS;RXV`&QD+G-O
M+C$`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<VAA7VEN:70`<VAA
M7W5P9&%T90!S:&%?9FEN86P`<&%R7VEN:71?96YV`'!A<E]M:W1M<&1I<@!P
M87)?9&ER;F%M90!M>5]P87)?<&P`<&%R7V-L96%N=7``7V9B<W,`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`<&%R7V5N=E]C;&5A;@!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!?7V1A=&%?<W1A<G0`>'-?:6YI=`!?7W-T
M87)T`%]F9&%T80!?7V)S<U]S=&%R=`!?9G1E>'0`7V5N9`!?961A=&$`1TQ)
M0D-?,BXT`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P!'3$E"0U\R+C(`1TQ)0D-?
M,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP`````````0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``(``0`!``$``0`"``$``0`!
M``$``0`!``$``@`"``D``@`!``$``0`%``(``@`#``$``0`"``(`!@`"``(`
M"``!``(``@`!``(``@`"``(`!P`!``(``@`"``(``@`%``4``0`!``$``0`!
M``(`!@`!``(``@`!``$``@`"``$``@`!``$`!0`$``(``@`!``$``P`!``$`
M`0`"``(``@````$``0`P`P``$````"`````4:6D-```'`&T$`````````0`'
M`"8#```0`````````+21E@8```D`=P0``!`````4:6D-```(`&T$```0````
MLY&6!@``!@""!```$````!)I:0T```4`C00``!````!R&6D)```$`)<$```0
M````=!EI"0```P"C!```$````!!I:0T```(`KP0`````````````````````
M````````\/\!```````````````2`_C_`0``````````````$@,@``(`````
M`````````!(#&`,"```````````````2`Q`#`@``````$````````##P_[UG
M``"\_P(`'#PMX)D#"`"__S!FG&>8@H+?!`!`$`````"8@IG?"?@@`P`````(
M`+_?``"\WP@`X`,0`+UGD/^]9V``O/\"`!P\+>"9`_!EG&<X`+'_H(&1W^B`
MF=]H`+__6`"U_U``M/](`+/_0`"R_S``L/\E&(`````BWA``I?\(`*;_$`"E
M9P@`IF<<`*1G'`"CKR@`HO\)^"`#`````*""AM_X@83?H("9WR\1$00E*,``
M^(""WP``0I!:`$`0.(*9WRB`D-_@@H+?.^@#?"T00P```$/<'`"RC]H$8I`@
M@9G?!`!$)@,`0C3X(`0`"?@@`]H$8J`0`*7?)3A``"B`@M^H@(/?0`-'_$"`
M@M\``*C<&&="9!P`IH\(`.+\0(""WP``9-P@9T)D`@##*`,`4B8``.C\$`#D
M_%X`8!08`.+\`P#()`@`I60$``0D)3```0``HMSX&`0`+1CC``$`A"0``&+\
M^O^&%`@`I60E$``!0("%W[""F=](`P3>^!`"`"T0X@`E,$`")4```&`FI60)
M^"`#``!`_#``0!`ED$``>(&9WT@#!-Y`@)/?"?@@`R0`M&=`@(3?8!YS9B4H
M@`(ER&`"I``1!&!DA&0H`$`0*("5W\""F=\)^"`#2`,$W@B"F=\)^"`#````
M`"@`H]\``"+>-`!B%&@`O]]@`+S?6`"UWU``M-](`+/?.`"QWS``L-\E$$`"
M0`"RWP@`X`-P`+UG"?@@`RB`D-\E($``(@!`$$@#`O[H@9G?"?@@`P````#@
M@H+?.^@#?"T@0P```(/<G/\`$(<*8*!P@IG?"?@@`T@#!-[-_P`0)9!``#@#
MI-X%`(`0L("9WV8)$00`````U/\`$,""F=]`@(3?)2B``B7(8`)O`!$$Z&.$
M9"4@0`#+_T`0.`.B_O/_`!"P@)G?KO\`$`0``B3(@)G?"?@@`P$`!"18@9G?
M"?@@`P``````````)0#@`P$`$00`````)<B``P(`'#Q$8YPG+>"?`R7X```@
M@(3?``"EWP@`IF?P_P$D).BA`R4X```E0```)4A``"50H`/8@)G?"?@@`P``
M``#__P`0`````````````````@`#/"T8>0#P8F-D*(!DW#"`8MPX`(1D!0!$
M$$"">=P#`"`3``````@`(`,`````"`#@`P`````"``,\+1AY`+AB8V0H@&3<
M,(!EW#@`A&0O**0`^Q`%`/XO!0`M**(`>R@%``4`H!`@@GG<`P`@$P`````(
M`"`#``````@`X`,``````````.#_O6<0`+S_`@`</"W@F0-H8IQG"`"P_RB`
MD-\8`+__(`,"D@P`0!38@8+?!`!`$#B`@M_8@9G?"?@@`P``1-Q`@)G?0!TY
M9\O_$00``````0`")"`#`J(8`+_?$`"\WP@`L-\(`.`#(`"]9P`````"``(\
M+1!9`/AA0F1`@%G<>!TY9\K_`!``````````````````````L/^]9T``O/\"
M`!P\+>"9`T@`O_\X`+;_,`"U_R@`M/\@`+/_&`"R_Q``L?\(`+#_00"`$-!A
MG&>0@8+?``!6W#T`P!(EH(````""@"68H``ED(``10!`$#T``R0$`$,0````
M``$`0H+\_T`4`0!29B^05`(`D!(```#0W@\``!(EB,`"/0`5)`B!F=\E(``"
M)3!``@GX(`,E*(`"!`!`%"T8$@(``&*`$0!5$``````(`##>]/\`%@@`,69(
M`+_?0`"\WS@`MM\P`+7?*`"TWR``L]\8`++?$`"QWR40``((`+#?"`#@`U``
MO6<`````+X@V`ON($0```'&N2`"_WP$`4F8M@!("0`"\WS@`MM\P`+7?*`"T
MWR``L]\8`++?$`"QWR40``((`+#?"`#@`U``O6<`````2`"_WR6```!``+S?
M.`"VWS``M=\H`+3?(`"SWQ@`LM\0`+'?)1```@@`L-\(`.`#4`"]9\+_`!`E
MD`````````#_O6?P`+S_`@`</"W@F0-88)QGX`"P_Z"!D-_H`+'_0(&9W_@`
MO_\```+>)2B@`R6(@`#8`*+_"?@@`P`````/`$`4(`"CCP!`!"0`\&,P!`!D
M$"4H8```H`,T"0"C%``````H@IG?`@`%)`GX(`,E("`"`P``$`$`0BP`````
M)1```-@`I-\```/>!@"#%/@`O]_P`+S?Z`"QW^``L-\(`.`#``&]9UB!F=\)
M^"`#``````````#@_KUG$`&\_P(`'#PMX)D#H%^<9_@`LO^@@9+?&`&__P@!
MM/\``;/_\`"Q_^@`L/\``$+>V`"B_P0`@!````````""@`X`0!0E@(``V`"C
MWP``0MYC`&(4&`&_WQ`!O-\(`;3?``&SW_@`LM_P`+'?Z`"PWP@`X`,@`;UG
M`````!""F=\)^"`#`````.__0!`EB$``X(&9WPGX(`,E("`".0!`$(B!F=\3
M`$.0TO]C)`4`8!03`%-D`0!CDO;_8!#@@9G?`````!,`0Y#2_V,D-0!@$,"!
MF=\)^"`#)2```L"!F=\E(&`""?@@`R6@0```H!0``!`"`"&@@@)H@9G?"?@@
M`P(`A"9`@(??&(&9WR4@0``E2&`")4```GACYV3__P8D`0`%)`GX(`,EH$``
M&(*9WR4HH`,)^"`#)2"``O__`R0%`&(0(`"BCP!``R0`\$(P'@!#$$"`F=^X
M@9G?"?@@`R4@@`(P@IG?"?@@`R4@@`+@@9G?"?@@`R4@(`+)_T`4B(&9WPGX
M(`,E("`"4(&9WPGX(`,E(``"J_\`$````````````0!CDM+_8R3)_V`4````
M``(`8Y*U_V`0`````,3_`!```````````)`@.6>*_Q$$)2"``N/_`!`P@IG?
M6(&9WPGX(`,`````L.^]9T`0O/\"`!P\+>"9`[!=G&<P$+/_&!"P_Z"!D]\E
M@(``0("$WS@0M/\@$+'_.(&9WT@0O_\H$++_"`"T9P``8MXEB*``_P\&)"4H
M@`*`8X1D"!"B_PGX(`,``````!`"``H`0!@`````)9!``/__0B00$$-D+1A]
M`/CO8X`9`&`4__]$)A4`0!0`````X(*"WSOH`WPM$$,`6(*9WP``1-PE,"`"
M"?@@`R4H``(($*/?``!BWAP`8A1($+_?0!"\WS@0M-\P$+/?*!"RWR`0L=\8
M$+#?"`#@`U`0O6<ED(```````!"!F=\E,$`"+P`%)`GX(`,E((`"Y/]`$.""
M@M\[Z`-\+1!#`*B!F=\``$3<)3A``B4P@`()^"`#)2@``N+_`!``````6(&9
MWPGX(`,`````H/^]9U``O/\"`!P\+>"9`WA<G&<@`++_H(&2WQ@`L?\0`+#_
M6`"__T@`M_]``+;_.`"U_S``M/\H`+/_)8"@`````X(``$7>/0`")"6(@``(
M`*7_`@!B%,"!F=\!`!!F"?@@`R4@``)`@)G?!`"E9R4@(`)@'CEGB_X1!"68
M0`!5`$`0):!``,"!F=\)^"`#)2!``"L04P!!`$`0!`"VCY"!E=_XL!8````B
M@B48(`(&`$`4/0`$)',``!`E&````0!B@`,`0!`!`&-D_/]$%``````O&'$`
M`!@#`&B!F=\"`&1F+2"#``GX(`,``+/>+9AV`AL`0!```&+^``"CW@``(H(M
M&'8```!EW`$`)&8``**@"`!`%#T`!B0)```0)1B@`````````(*``0"$9"<`
M0!`!`&*@)1B@`/K_1A0!`*5D/0`$)`$`8F0``&2@```#@@$`0F0!`!!F_/]@
M%/__0Z`(`*/?``!"WDL`8A18`+_?4`"\WT@`M]]``+;?.`"UWS``M-\H`+/?
M(`"RWQ@`L=\0`+#?"`#@`V``O6<```*"`0"49@$`$&;M_T`0__^"H@```H(!
M`)1F`0`09O?_0!3__X*BYO\`$`````#<_P`0)1B@`)"!E=\``+?>``#BWBH`
M0!`E$.`"):````@`0]PE((`""`!"9/S_8!0!`)0F`P"$)/@@!``H@(+?,`-#
MC!0`8!20@IG?:(&9WP$``R0)^"`#,`-#K,W_0!`E($``,(&9W_BP%``E,,`"
M"?@@`R4HX`(E($````"B_@$`@B;X$`(`+2""````@/R1_P`0!`"TKR4H@``)
M^"`#)2#@`B4@0`"Z_T`0``"B_O/_`!#XL!0`E?\`$&B!F=\0``0DW?\`$"6@
M``!8@9G?"?@@`P````#@_[UG$`"\_P(`'#PMX)D#T%F<9P@`L/_@@I#?.^@#
M?!@`O_\M@`,"2("'WT"`A=_P@)G?`(*&WP``!-X@I>=D"?@@`Y!CI61`@(C?
M0("%WU"`AM_P@9G?```$WA!G"&4E2```)3@``0GX(`.P8Z5D&`"_WQ``O-\(
M`+#?"`#@`R``O6<`````\/^]9P``O/\"`!P\+>"9`TA9G&?@@H+?.^@#?`@`
MO_](@(??0("%WRT00P#P@)G?`(*&WP``1-P@I>=D"?@@`Y!CI60(`+_?``"\
MWP@`X`,0`+UG`````+#?O6=`(+S_`@`</"W@F0/P6)QG,""R_Z"!DM]((+__
MT(*9WS@@L_\@(+#_*""Q_P``0MX(`+!G&""B_PGX(`,0$+-G0(")WT"`A]\8
M@9G?)2```LAC*64E0$``T&/G9`$0!B0)^"`#`0`%)#B!F=\E(``"`!`&)`GX
M(`,E*&`"`(`"`!P```9H@9G?`0`$)@GX(`,EB``"%P!`$"4@0`#(@9G?)3``
M`@GX(`,E*&`"+8A1`"4@0````""B&""CWP``0MX)`&(42""_WT`@O-\X(+/?
M,""RWR@@L=\@(+#?)1"```@`X`-0(+UG6(&9WPGX(`,`````\/\`$"4@```"
M``,\+1AY`/!78V18@'G<N_\`$`````"P[KUG.!&\_P(`'#PMX)D#V%><9R@1
MMO\`$;'_H(&6WR6(@`!`@)G?0("$WT@1O_\($;+_^!"P_T`1OO\P$;?_(!&U
M_Q@1M/\0$;/_``##WNACA&1@'CEG)9"@``P`I6?H$*/_:/T1!`````"(@IG?
M+P`%)"4@(`()^"`#)8!``!D`0!#@@)G?0("$WT"`F=\E*"`"N",Y9['^$03X
M8X1D)1`@`N@0I-\``,/>?@"#%$@1O]]`$;[?.!&\WS`1M]\H$;;?(!&UWQ@1
MM-\0$;/?"!&RWP`1L=_X$+#?"`#@`U`1O6<`````)2!``@GX(`-`@)+?2(&9
MWPAD168)^"`#)2!``.#_0!`EN$``0("5WT"`E-\``.*"Z`"S9Q!DM69!`$`0
M&&249@8``!+0@)G?)2C@`@GX(`,E(``",@!`$$B!F=_`@9G?"?@@`R4@X`+_
M_T-D+1CC`B7P0``K$.,"!P!`%"\`!"0,```0P(&9WP``8*#__V-D!`#C$@``
M`````&*`^O]$$,"!F=\)^"`#)2#@`B7P0`#`@9G?"?@@`R4@(`(M$%X``0!"
M9``00BRU_T`0&(&9WR4@8`(E4"`")4B@`B5`X`(E.(`"`!`&)`GX(`,!``4D
M&(*9WQ``I6<)^"`#)2!@`@<`0!1(@9G?,`"BCP"``S0`\$(P&@!#$"B"F=](
M@9G?"&1%9@GX(`,E(```G/]`$"6X0````.*"P?]`%``````%```2````````
M`I+2_T(D!0!`$`````!`@)??`0`>)-/_`!#@8_=F`0`"DNS_0!!(@9G?^?\`
M$$"`E]\``````0`%)`GX(`,E(&`"Y/]`%$B!F=]`@(3?0("9WR4H8`*X(SEG
M-/X1!/ACA&3@@)G?"?@@`R4@8`*`_P`0`````%B!F=\)^"`#``````````#@
M_[UG$`"\_P(`'#PMX)D#(%6<9U""F=\O``4D"`"P_Q@`O_\)^"`#)8"```(`
M0!#@@)G?`0!09`GX(`,E(``"&`"_WQ``O-\(`+#?"`#@`R``O6<`````P.^]
M9S`0O/\"`!P\+>"9`\A4G&<H$+/_H(&3WS@0O_\@$++_&!"Q_Q`0L/\``&+>
M"!"B_S0`@!````````""@#$`0!`ED(``P(&9WPGX(`,``````0!&9"6`0``!
M$,(L,0!`$,B!F=\(`+%G)2`@`@GX(`,E*$`"__\"9BT0(@(K&"(""`!@%"\`
M!"0)```04(*9WP```````$"@__]"9`4`41`O``4D``!#@/K_9!!0@IG?+P`%
M)`GX(`,E("`"$0!`$"L8(@(5`&`4`````."`F=\)^"`#)2`@`@@0I-\``&/>
M$@"#%#@0O]\P$+S?*!"SWR`0LM\8$+'?$!"PWP@`X`-`$+UG0("$W^"`F=\)
M^"`#X&.$9/#_`!``````Z_\`$```0*#L_P`0)1```%B!F=\)^"`#````````
M``"0_[UG6`"\_P(`'#PMX)D#B%.<9T``M?^@@97?,`"S_R@`LO\@`+'_&`"P
M_V@`O_]@`+[_4`"W_T@`MO\X`+3_``"BWD"`D-]`@)+?D(&3WP@`HO\$`+%G
M8!X09B!D4F8E*"`")<@``E/\$00E($`"$0!`$`0`HX\``&+>^!@#`"T00P`(
M`$/<]?]@$```0_P0`$/<"`!"9/W_8!0``$/\)2@@`B7(``)#_!$$)2!``O'_
M0!0$`*./0("2WY"!D]\P9%)F)2@@`B7(``(Z_!$$)2!``A(`0!`$`*./``!B
MWO@8`P`M$$,`"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@%```0_PE*"`"
M)<@``BG\$00E($`"\/]`%`0`HX]`@)+?D(&3WSAD4F8E*"`")<@``B#\$00E
M($`"$@!`$`0`HX\``&+>^!@#`"T00P`(`$/<]?]@$```0_P`````$`!#W`@`
M0F3]_V`4``!#_"4H(`(ER``"#_P1!"4@0`+P_T`4!`"CCT"`DM^0@9/?2&12
M9B4H(`(ER``"!OP1!"4@0`(3`$`00("4WP0`HX\``&+>^!@#`"T00P`(`$/<
M]/]@$```0_P0`$/<"`!"9/W_8!0``$/\)2@@`B7(``+U^Q$$)2!``O'_0!0$
M`*./0("4WY"!D]]09))F)2@@`B7(``+L^Q$$)2!``A(`0!`$`*./``!BWO@8
M`P`M$$,`"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@%```0_PE*"`")<@`
M`MO[$00E($`"\/]`%`0`HX]`@)+?D(&3WV!D4F8E*"`")<@``M+[$00E($`"
M$P!`$$"`EM\$`*./``!BWO@8`P`M$$,`"`!#W/3_8!```$/\$`!#W`@`0F3]
M_V`4``!#_"4H(`(ER``"P?L1!"4@0`+Q_T`4!`"CCT"`EM^0@9/?Z&/29B4H
M(`(ER``"N/L1!"4@0`(3`$`00(">WP0`HX\``&+>^!@#`"T00P`(`$/<]/]@
M$```0_P0`$/<"`!"9/W_8!0``$/\)2@@`B7(``*G^Q$$)2!``O'_0!0$`*./
M0(">WY"!D]]P9-)G)2@@`B7(``*>^Q$$)2!``A,`0!!`@)??!`"CCP``8M[X
M&`,`+1!#``@`0]ST_V`0``!#_!``0]P(`$)D_?]@%```0_PE*"`")<@``HW[
M$00E($`"\?]`%`0`HX]`@)??D(&3WX!D\F8E*"`")<@``H3[$00E($`"$@!`
M$`0`HX\``&+>^!@#`"T00P`(`$/<]?]@$```0_P`````$`!#W`@`0F3]_V`4
M``!#_"4H(`(ER``"<_L1!"4@0`+P_T`4!`"CCT"`DM^0@9/?D&129B4H(`(E
MR``":OL1!"4@0`(2`$`0!`"CCP``8M[X&`,`+1!#``@`0]SU_V`0``!#_```
M```0`$/<"`!"9/W_8!0``$/\)2@@`B7(``)9^Q$$)2!``O#_0!0$`*./0("2
MWY"!D]_X8U)F)2@@`B7(``)0^Q$$)2!``A(`0!`$`*./``!BWO@8`P`M$$,`
M"`!#W/7_8!```$/\`````!``0]P(`$)D_?]@%```0_PE*"`")<@``C_[$00E
M($`"\/]`%`0`HX]`@(3?)2@@`B7(``(X^Q$$H&2$9`4`0!`E*$``0("9W[@C
M.6>(_!$$@&3D9D"`A-\E*"`")<@``BW[$02X9(1D!@!`$"4H0`!`@(3?0("9
MW[@C.6=\_!$$T&2$9$"`A-\E*"`")<@``B'[$03@9(1D&@!`$"4H0`!`@)G?
MN",Y9W'\$03H8\1F"`"CWP``HMX?`&(40("%WT"`F=]H`+_?8`"^WU@`O-]0
M`+??2`"VWT``M=\P`+/?*`"RWR``L=\8`+#?4&2$9C@`M-\(9:5DN",Y9US\
M`!!P`+UG0("$WR4H(`(ER``"`?L1!/!DA&3E_T`0)2A``$"`F=^X(SEG4?P1
M!'!DQ&??_P`0`````%B!F=\)^"`#``````````#0_[UG(`"\_P(`'#PMX)D#
MH$V<9Q@`L?\0`+#_*("1WZ"!D-\H`+__```$WA``(H[__P,D"`"D_PL`0Q!`
M@(3?"`"DWP```]X8`(,4*`"_WR``O-\8`+'?$`"PWP@`X`,P`+UG`````$"`
MF=\$`*5G8!XY9];Z$01P9(1D"`!`$````````$*`!0!`$``````P`$(X*Q`"
M`.G_`!`0`"*N)1```.;_`!`0`"*N6(&9WPGX(`,`````\/^]9P``O/\"`!P\
M+>"9`^A,G&>8@9G?"`"__PGX(`,`````L(&9WPGX(`,E($```@!`$`@`O]\`
M`$+<``"\WP@`X`,0`+UGL/^]9T``O/\"`!P\+>"9`Z!,G&<P`+/_*`"R_T"`
MD]^@@9+?0("9WR``L?](`+__.`"T_Q@`L/\``$+>)8B```0`I6<0961F8!XY
M9P@`HO^?^A$$`````!4`0!`E@$````!"@!(`0!!P@9G?)2@@`@GX(`,E(``"
M'0!`$,"!F=\(`*/?``!"WC,`8A1(`+_?0`"\WS@`M-\P`+/?*`"RWR``L=\8
M`+#?"`#@`U``O6<(`*/?``!"WB<`8A0E*"`"0("9WT@`O]]``+S?.`"TWR@`
MLM\@`+'?&`"PWQ!E9&8P`+/?N",Y9\_[`!!0`+UG"?@@`R4@(`+`@9G?)2``
M`@GX(`,EH$``:(&9WRT@@@()^"`#`@"$9$"`B=]`@(??&(&9WP$`!20E4``"
M"&0I925`(`(89.=D__\&)"4@0``)^"`#):!```@`H]\``$+>V_]B$"4H@`)8
M@9G?"?@@`P``````````$("]9]A_O/\"`!P\+>"9`SA+G&=`@(/?__\"/.!_
MOO_`?[7_N'^T_^A_O__0?[?_R'^V_[!_L_^H?[+_H'^Q_YA_L/]T?D5DX/V]
M9R6H@`"@@00T)3!@`"T@A0`0`*5G+2B%`*"!GM_H8\1DH($&-"TPP@`0`*)G
M+1#"`!``H_\0`*=G``##WYB!!C0M,,<```##_$"`@]]`@)3?*&5C9'A^0_Q`
M@(/?8!Z49N!C8V2`?D/\0("#WR7(@`(P96-DL'Y#_$"`@]^(?D#\.&5C9+A^
M0_Q`@(/?T'Y`_$!E8V3`?D/\0("#WZ!^0/Q(96-DR'Y#_$"`@]]096-DD'Y#
M_$"`@]]896-D%_H1!)A^0_P%`$`0F(&9WR6`0````$*`=P%`%``````)^"`#
M`````+"!F=\)^"`#)2!``+X`0!#__Q$\``!3W+T`8!*0?C!FP(&9WPGX(`,E
M(&`":(&9WW@@`@`)^"`#`0"$9```:((E@$``#P``$26(0`!`@(/?:&5R9```
M```8@9G?_P`(,24@``(E.$`"__\&)`$`!20)^"`#`0!S9@``:(+V_P`5`@`0
M9O__%CRH?M-FH($"-"T04P`0`*-G='[69D"`A-]`@)+?+9A#`*"!`C0M$%8`
MT&2$9"VP0P`$```0V!]29@@`9-X2`(`0"`!S9B7(@`+9^1$$)2C``OG_0!`E
M@$````!"@/;_0!`ER$`",/H1!"4@``+R_T`0X("9WPGX(`,E(``"&`!`%"6`
M0```````__\2/'A^4F9`@)/?H($"-"T04@`0`*-G+9!#`-@?<V8``%#>#@``
M$L"!F=\```*";P!`$"7(8`(9^A$$)2```F,`0!3@@)G?"`!0WO?_`!8(`%)F
M`````,"!F=\`````)2```@GX(`-`@)/?P(&9WR4@(`()^"`#);!```"P%@``
M$`(`(;#"`FB!F=\$!,0F"?@@`R6P@`!`@(K?0("'WQB!F=\E($``)5@@`G!E
M2F409&EF)4```GAEYV3__P8D`0`%)`GX(`,ED$``R(*9W\`!!20)^"`#)2!`
M`O__`R0'`&(4V(*9WPGX(`,`````$0`#)```28SF`",5T(&"W___$3S8?B5F
MH($"-$"!F=\M$$4`$`"C9RTH0P`)^"`#)2!``@H`0!0E@$``H($"-"T040`0
M`*-G+;A#`/A^XHX`0`,D`/!",%,`0Q"8@9G?T(&"WT"`AM^H@IG?``"GW@``
M1-PE0$`"R&7&9`GX(`,!``4D)8@``!``HV>8@0(T+1!#````0]P``,+?G`%B
M%"40(`(@`KUGZ'^_W^!_OM_8?[S?T'^WW\A_MM_`?[7?N'^TW[!_L]^H?[+?
MF'^PWZ!_L=\(`.`#\'^]9P`````E(``""?@@`P@`4F:0_T`0)8!``)[_`!#`
M@9G?`````)G_`!`E@```D'XP9@````"@@0(T+1!0`!``HV<M@$,`='XQ9J"!
M`C0```3>+1!1``X`@!`MB$,`)<B``@`````]^1$$)2@@`@0`0!`E($````!"
M@`X`0!3@@)G?"``09@``!-[V_X`4)<B``FB!F=\-``0D"?@@`T"`D]\@97-F
M)8!``"6(0``P_P`04P`()`GX(`,`````(?]`%"680`#O_P`0"``09@A_XXX)
M^"`#&`"C_Q@`H]\`$`(`J?]B%-"!@M_X?N*.P`$#)/\!0C"D_T,4T(&"WVB!
MF=\)^"`#)2#``G1^)6:@@0,T+1AE`!``I&<M*&0`0("$WR7(@`(@9H1D#/D1
M!"6(0`!X`$`0)2A``&"`F=^%^Q$$``"DWG,`0!`EL$``P(&9WPGX(`,E(,`"
M`!`"``0`0R@0`&`4);A``$"`A=_0@)G?_/_D9BAFI60)^"`#+2#$`@@`0!0$
M``(D]P#B$OO_XB8M$,("``!#@"\``B3R`&(0`````"B`E=___P,D$`"BCMP`
M0Q#__P4\6@!`$`"!F=]`@(+?0("%WT"`A-^X(UED"&6E9'!DA&0V^A$$&`"Y
M_]""F=]`@)3?"?@@`___%21`@(??$&>79AB!F=]`@)3?)5C@`B500``09&EF
M)4!``DAFYV3__P8D`0`%)"4@(`()^"`#$0`6)!0``!!89I1F``````GX(`,`
M``````!"C!0`5A30@IG?"?@@`P$`$"88@9G?)5@``B500``09&EF)4!``B4X
M@`+__P8D`0`%)"4@(`()^"`#``"W_\B"F=_``04D"?@@`R4@(`+I_Z(2V(*9
MWS""F=\)^"`#)2!``A``HM\8`+G?Z&-$9`GX(`,E*"`":("9W_3]$00E("`"
M._\`$!``HV=`@(;?J(*9WP``I]X``$3<)4!``HAEQF0)^"`#`0`%)##_`!`E
MB````````&B`F=_D_1$$)2```N"`F=\)^"`#)2```B?_`!`EB$``C?\`$```
MMMX0`*"N`(&9WR4H```)^"`#)2#``J/_0!`EH$``>(*9WR4@0``"``8D[O\%
M)`GX(`/__Q`\^'\59J"!`C00`*-G+1!5`"VH0P!(@IG?!@`&)"4HH`()^"`#
M)2"``J"!`C00`*-G+1!0`"T00P#X?T.0!0!@%'B"F=_Y?T.00P`$)($`9!``
M````)3```"4H```E((`""?@@`___$#QP@)G?8P<1!/A_%F80`*-G):A``*"!
M`C0M$%8`!```$"VP0P`E*,`"?`<1!"4@H`)(@IG?`(`&-"4HP`()^"`#)2"`
M`@`P`@#V_\`<>("9WX"!F=\E((`""?@@`[!_$&:@@0(T+1!0`!``HV<MH$,`
M@("9WR4HH`(E((`"X0<1!!@`$&:@@0(T0("#WRT04``0`*1G+8!$`"@`%69H
M979D````````B)(8@9G?)2```B4XP`+__P8D`0`%)`GX(`,"`!!F]_^P%@$`
ME&;__P(\R']*9*"!`S0M&&H`$`"D9RU09`"@@0,T+1AB`$"`B]]`@(??$`"B
M9RT08@`8@9G?$&=K91!D:68E0$`".&;G9/__!B0!``4D)2`@`O!_0*`)^"`#
M`````$"`@M\P@IG?)2!``K@C0F0)^"`#&`"B_Q``HM\8`+G?Z&-$9`GX(`,E
M*"`":("9WU[]$00E("`"I?X`$!``HV<`````='ZE9$"`A-^@@0(T+1!%`!``
MHV<M*$,`)<B``@;X$01P9(1D=/]`$````````$*`<?]`$#``0C@K$`(`%?\`
M$!``HJX(`+7>#?^@$L"!F=\)^"`#)2"@`@0`0RP(_V`40("%W]"`F=_\_T)D
M,&:E9`GX(`,M(*("`?\`$`JPH@+Z?T6000`$)'W_I!1X@IG?^W]$D'O_@Q0E
M,```_']$D$@``R1W_X,4`````/U_0Y!%``(D<_]B%``````E((`"`@`&)`GX
M(`/&_P4D2(*9WR4HH`(E((`""?@@`RD`!B1`@(O?0("'WQ!G:V48@9G?)5"@
M`A!D:68E0$`".&;G9/__!B0!``4DJO\`$"4@(`)8@9G?"?@@`P``````````
ML/^]9T``O/\"`!P\+>"9`^A`G&<0`+#_X(*0WSOH`WPP`+3_(`"R_Q@`L?](
M`+__.`"U_R@`L_\M$`,"``!3W$"`D=^@@9+?0("$W[``8Y($`+1G8!XQ9@``
M0MXE*(`"4&2$9"7((`*Q`&.B"`"B_ZGW$00`````!`!`$#$``R0``$2`?`"#
M$`````"(@)G?,_L1!``````[Z`-\+1`#`@``4]Q`@(7?:(*9WR4@8`(#``<D
M`0`&)`GX(`-P9J5D$`!`$"680``0`$+<.^@#?"VH`P)`@(;?``!%W%B"F=\`
M`*3>"?@@`WAFQF00`&+>``!%W`P`HHR`!4)\;@!`%&"!F=\[Z`-\+:@#`D"`
MA=]H@IG?``"DW@,`!R0!``8D"?@@`X!FI60-`$`0)9A``$"`A-\E*(`")<@@
M`G;W$03X8X1D)3!``%$`P!`0`&+>6(*9WP``1=P)^"`#``"DWCOH`WPM@`,"
M```3WD"`A=^X@IG?)2!@`@$`!B2(9J5D"?@@`RB`E=]`@(;?6(*9WR4H0``E
M(&`""?@@`Z!FQF1`@(3?```"WB4H@`+H8X1D)<@@`ECW$02Q`$"@)8!``"$`
M0!`X`Z+^R(*9W\`!!20)^"`#)2```@$`0R0"`&,L"P!@%!$``R0)`$,0*("#
MWT"`A-]``V/<*(&9WP``9=PE.$``)3```@GX(`/09H1D"`"CWP``0MXK`&(4
M2`"_WT``O-\X`+7?,`"TWR@`L]\@`++?&`"QWQ``L-\(`.`#4`"]9P`````H
M@(+?D("9W]?\$01``T3<)8!``-K_0!0X`Z+^0("$WRB!F=\)^"`#J&:$9```
M```!`$*`B?]`$(B`F=^"_P`0```````````H@(/?0("9WT`#8]P``$3<@"(Y
M9R3X$00``&7<K/\`$```````````"?@@`P``I-Z0_P`0`````%B!F=\)^"`#
M``````````#`_[UG,`"\_P(`'#PMX)D#$#Z<9R``LO^@@9+?.`"__Q@`L?\0
M`+#_F("9WR@`L_\``$+>)8B```@`HO]"^A$$`````%""F=\O``4D)2!```GX
M(`,E@$```@!`$."`F=\!`%!D)2```@GX(`,H@)/?$`!CCO__!"05`&00)8!`
M``<`8!``````!0`@$@```````"*"'`!`%$"`A=\`````"`"CWP``0MXO`&(4
M.`"_WS``O-\H`+/?(`"RWQ@`L=\0`+#?"`#@`T``O6<`````0("$WT"`F=\$
M`*5G8!XY9]?V$01P9(1D'0!`$````````$.`&@!@$#``8S@K&`,`W_\`$!``
M8ZX(@9G?!``&)'!EI60)^"`#)2```N#_0!0`````"`"CWP``0MX.`&(40("9
MWS@`O]\P`+S?*`"SWR``LM\0`+#?)2`@`A@`L=^0(#EG1O<`$$``O6<`````
MS_\`$!``8*Y8@9G?"?@@`P````````````````````!`_;UGL`*\_P(`'#PM
MX)D#D#R<9Z"!F-^X`K__J`*R_Z`"L?^8`K#_```"WP@`I6>(`J+_.`"(9'@`
MC&0E2*``_P`+/`````````?=```#C3XP!P`^$@<`.%8&`#X^!P``_T(P)1!'
M`*`8`WP#^$=].#(&``(<(P`E$$<`)##+``/X8WPE$$8`"``(90``(_T(`"+]
M[/^(%1``*65P`*W?>`"LWX``H]\8`*O?(`"JWR@`J=\P`*C?.`"GWT``K]\"
M```0``*Y9"5XP`!``*;<``"BW"5P8``F$,(`)A!-`"802P!X&`(`^A<"`"48
M8@`#^&-\@`"C_`@`I60E:(`!)5A``25@P`$E4"`!)4@``25`X`#L_[D4)3C@
M`0``BMP0`(;<&`"'W`@`B-P(`*W?@EH+/)EY:V4@`(G<^AX*`'@1"@`E$$,`
M+6BK`288QP"Z8`@`N"\(`"4HK``M:*D!`_A"?"08:``#^*Q\)AAG`"T030`0
M`*W?+1!#`"88S``#^$)\)!AJ`"UHJP$M:*<!>'D"`/K.`@`F&&8`NH`*`+AW
M"@`M&&T`)6CY`25PT`$M&&T`&`"MWR8HK@`#^&-\)"BB`"UHJP$F**P`+6BF
M`7C)`P#ZA@,`N'\"`+H0`@`E>.(!+1"M`"4H,`,@`*W?+1!%`"8HSP$#^$)\
M`_C.?2UHJP$D**,`+6"L`7C)`@#ZA@(`)BBN`+AO`P"Z&`,`)6BC`2THK``E
M&#`#*`"LWRTHHP`F&.T!`_BE?`/X[WTD&&(`+6"+`2U@C@%XR04`^H8%`"88
M;P"X=P(`NA`"`"5PP@$M&&P`)1`P`RT88@`#^&Q\,`"CWR80K@$D$$4``_BM
M?2T8:P`M&&\`>,D,`/J&#``F$$T`+1!#`"48,`,M$$,`N'\%`+HH!0`E>.4!
M`_A%?#@`HM\F&,\!)!AL``/XSGTM$$L`+1!-`'C)!0#ZA@4`)AAN`"T88@`E
M$#`#+1AB`+AO#`"Z8`P`)6BL`0/X;'Q``*/?)A#M`20010`#^.]]+1AK`"T8
M;@!XR0P`^H8,`"803P`M$$,`)1@P`RT00P"X=P4`NB@%`"5PQ0$#^$5\2`"B
MWR88K@$D&&P``_BM?2T02P`M$$\`>,D%`/J&!0`F&&T`+1AB`"40,`,M&&(`
MN'\,`+I@#``E>.P!`_AL?%``H]\F$,\!)!!%``/XSGTM&&L`+1AM`'C)#`#Z
MA@P`)A!.`"T00P`E&#`#+1!#`+AO!0"Z*`4`)6BE`0/X17Q8`*+?)ACM`208
M;``#^.]]+1!+`"T03@!XR04`^H8%`"88;P`M&&(`)1`P`RT88@"X=PP`NF`,
M`"5PS`$#^&Q\8`"CWR80K@$D$$4``_BM?2T8:P`M&&\`>,D,`/J&#``F$$T`
M+1!#`"48,`,M$$,`N'\%`+HH!0`E>.4!`_A%?&@`HM\F&,\!)!AL``/XSGTM
M$$L`+1!-`'C)!0#ZA@4`)AAN`"T88@`E$#`#+1AB`+AO#`"Z8`P`)6BL`0/X
M;'QP`*/?)A#M`20010`#^.]]+1AK`"T8;@!XR0P`^H8,`"803P`M$$,`)1@P
M`RT00P"X=P4`NB@%`"5PQ0$#^$5\>`"BWR88K@$D&&P``_BM?2T02P`M$$\`
M>,D%`/J&!0`F&&T`+1AB`"40,`,M&&(`N'\,`+I@#``E>.P!`_AL?(``H]\F
M$,\!)!!%``/XSGTM&&L`+1AM`'C)#`#ZA@P`)A!.`"T00P`E&#`#+1!#`+AO
M!0"Z*`4`)6BE`0/X17R(`*+?)ACM`208;``#^.]]+1!+`"T03@!XR04`^H8%
M`"88;P"X=PP`NF`,`"5PS`$M&&(`D`"LWR40,`,M&&(`)A"N`0/X8WP#^*U]
M)!!%`"U@BP$M8(\!^LX#`"8030!X>0,`)7CY`2T03`"X9P4`NB@%`"5@A0&8
M`+G?+1!/``/X0GPF*,P!+<@K`_J&`@`#^,Y])"BC`'AY`@`M:"T#)BBN`"5X
M\`$M**T``_CO?;AO`P"Z&`,`)6BC`2THKP"@`*_?`_BY?"88C0$M>.L!`_B,
M??J&&0`D&&(`>%D9`"UP[@$F&&P`)5AP`2T8;@`#^&M]N'<"`+H0`@`M>&L`
M)7#"`:@`J]_9;@,\H>MC-`/X\'TF$*X!^HX0`"8010`M6&,!>"D0`"U8;`$E
M*+$``_A"?"T02P`#^*5\N&<9`+K(&0`E8)D!+5A%`+``HM\#^'E])BC,`0/X
ML7TM$$,`)FBO`/I^&0!X*1D`+1!1``/XK7TE**\`+1!-``/XI7RX;Q``NH`0
M`"5HL`$M*$4`N`"BWP/XKWPF@(T!`_C1?2T00P`F<`L"^H8/`'A9#P`M$%$`
M`_C.?258<`$M$$X``_AK?;AW&0"ZR!D`)7#9`2U82P#``*+?`_AY?2:`K@$#
M^)%]+1!#`"9@!0+ZAAD`>"D9`"T040`#^(Q])2BP`"T03``#^*5\N&</`+IX
M#P`E8(\!+2A%`,@`HM\#^*]\)H#,`0/XL7TM$$,`)F@+`OJ&#P!X60\`+1!1
M``/XK7TE6'`!+1!-``/X:WVX;QD`NL@9`"5HN0$M6$L`T`"BWP/X>7TF@(T!
M`_C1?2T00P`F<`4"^H89`'@I&0`M$%$``_C.?24HL``M$$X``_BE?+AW#P"Z
M>`\`)7#/`2TH10#8`*+?`_BO?":`K@$#^)%]+1!#`"9@"P+ZA@\`>%D/`"T0
M40`#^(Q])5AP`2T03``#^&M]N&<9`+K(&0`E8)D!+5A+`.``HM\#^'E])H#,
M`0/XL7TM$$,`)F@%`OJ&&0!X*1D`+1!1``/XK7TE*+``+1!-``/XI7RX;P\`
MNG@/`"5HKP$M*$4`Z`"BWP/XKWPF@(T!`_C1?2T00P`F<`L"^H8/`'A9#P`M
M$%$``_C.?258<`$M$$X``_AK?;AW&0"ZR!D`)7#9`2U82P#P`*+?`_AY?2:`
MK@$#^)%]+1!#`"9@!0+ZAAD`>"D9`"T040`#^(Q])2BP`"T03``#^*5\N&</
M`+IX#P`E8(\!+2A%`/@`HM\#^*]\)H#,`0/XL7TM$$,`)F@+`OJ&#P!X60\`
M+1!1``/XK7TE6'`!+1!-``/X:WVX;QD`NL@9`"5HN0$M6$L```&BWP/X>7TF
M@(T!`_C1?2T00P`F<`4"^H89`'@I&0`M$%$``_C.?24HL``M$$X``_BE?+AW
M#P"Z>`\`)7#/`2TH10`(`:+?`_BO?":`K@$#^)%]+1!#`"9@"P+ZA@\`>%D/
M`"T040`#^(Q])5AP`2T03``#^&M]N&<9`+K(&0`E8)D!+5A+`!`!HM\#^'E]
M)H#,`0/XL7TM$$,`)F@%`OJ&&0!X*1D`+1!1``/XK7TE*+``+1!-``/XI7RX
M;P\`NG@/`"5HKP$M*$4`&`&BWP/XKWPF@(T!`_C1?2T00P`F<`L"^H8/`'A9
M#P`M$%$``_C.?258<`$M$$X``_AK?;AW&0"ZR!D`)7#9`2U82P`@`:+?`_AY
M?2:`K@$#^)%]+1!#`"9@!0+ZAAD`>"D9`"T040`#^(Q])2BP`"T03``#^*5\
MN&</`+IX#P`M*$4`)6"/`2@!HM\#^+!\)GC,`0/XL7TM$$,`)FCK`?I^$`!X
M61``+1!1``/XK7TE6&\!+1!-``/X:WVX;QD`NL@9`"5HN0$M6$L`,`&BWP/X
M;WTFR(T!^HX/`"T00P`#^,Y])L@E`W@I#P`M$$X``_@Y?R4HL0`M$%D`N'<0
M``/XI7RZ@!``+2A%`"5PT`$X`:+?)H"N`0/XN7PM$$,``_B,?298"P+ZCAD`
M>($9`"T03``#^&M]N&</`"T02P"Z>`\`)5@1`B5@CP$M$$L`0`&KWR:`S`$#
M^$]\+5AC`280!0(#^*U]+5AM`0/X0GSZ;@\`>"D/`+@?&0`M6&(!NL@9`,8C
M`CPE&'D`)2BM`$@!N=\W[T(TN!`"``/X;7PM6&4!)2B#`0/X:WTD@(T!)"BO
M`"W((@,#^,Y]+<@N`_J."P`E*+``N'</`'B!"P"Z>`\`)7#/`2THN0`E>!$"
M+2BO``/XKWQ0`:7?)1AN`"3(S0$M**(`)!AK``/XC'TM8*P`^H8/`"48>0"X
M+PL`>,D/`+I8"P`E**L`+1AL`"58,`-8`;G?`_BL?"T8:P`E6,4!`_AC?"2`
MS`$D6&\!+<@B`RW(+0/ZC@,`)5AP`;AO#P!X@0,`NG@/`"5HKP$M6'D!)7@1
M`BU8;P$#^&]]8`&KWR4HK0`DR*P!`_C.?20HHP`M6&(!+5AN`;B'`P!X<0\`
M)2BY`+H8`P#ZS@\`)1@#`BTHJP`E6-D!:`&YWP/X;GPM**L`)5BC`0/XI7PD
M@*X!)%AO`2W((@,MR"P#^HX%`"58<`&X9P\`>($%`+IX#P`E8(\!+5AY`25X
M$0(M6&\!`_AO?7`!J]\E&&P`),B.`0/XK7TD&&4`+5AB`2U8;0&XAP4`>&D/
M`"48>0"Z*`4`^LX/`"4H!0(M&&L`)5BY`7@!N=\#^*U\+1AK`"58A0$#^&-\
M)("-`218;P$MR"(#+<@N`_J.`P`E6'`!N'</`'B!`P"Z>`\`)7#/`2U8>0$E
M>!$"+5AO`0/X;WV``:O?)2BN`"3(S0$#^(Q])"BC`"U88@$M6&P!N(<#`'AA
M#P`E*+D`NA@#`/K.#P`E&`,"+2BK`"58F0&(`;G?`_AL?"THJP`E6,,!`_BE
M?"2`S`$D6&\!+<@B`RW(+0/ZC@4`)5AP`;AO#P!X@04`NG@/`"5HKP$M6'D!
M)7@1`BU8;P$#^&]]D`&KWR48;0`DR*P!`_C.?20890`M6&(!+5AN`;B'!0!X
M<0\`)1AY`+HH!0#ZS@\`)2@%`BT8:P`E6-D!F`&YWP/XKGPM&&L`)5BE`0/X
M8WPD@*X!)%AO`2W((@,MR"P#^HX#`"58<`&X9P\`>($#`+IX#P`E8(\!+5AY
M`25X$0(M6&\!`_AO?:`!J]\E**P`),B.`0/XK7TD**,`+5AB`2U8;0&XAP,`
M>&D/`"4HN0"Z&`,`^LX/`"48`P(M**L`)5BY`:@!N=\#^&U\+2BK`"58@P$#
M^*5\)("-`218;P$MR"(#+<@N`_J.!0`E6'`!N'</`'B!!0"Z>`\`)7#/`2U8
M>0$E>!$"+5AO`0/X;WVP`:O?)1AN`"3(S0$#^(Q])!AE`"U88@$M6&P!N(<%
M`'AA#P`E&'D`NB@%`/K.#P`E*`4"+1AK`"58F0&X`;G?`_BL?"T8:P`E6,4!
M`_AC?"2`S`$D6&\!+<@B`RW(+0/ZC@,`)5AP`;AO#P!X@0,`NG@/`"5HKP$M
M6'D!)7@1`BU8;P$#^'E]P`&KWR4HK0`D>*P!`_C.?20HHP`M6&(!+5AN`;B'
M`P!X<1D`)2BO`+H8`P#Z?AD`)1@#`BTHJP#(`;#?)5C/`2THJP`#^&Y\)5BC
M`0/XI7PD>*X!)%AY`2V``@(M@`P">(D%`/J6!0"Z8!D`)5AO`;A_&0`E>.P!
M+5AP`25@,@(M6&P!T`&LWR48;P`#^&M]),CN`0/XK7TD&&4`+6""`2U@C0$E
M&'D`>&D+`/K."P`M&&P`)6"Y`;AO!0"Z*`4`)2BE`=@!L-\M&&P``_AC?`/X
MK7PE8.4!))#M`2V``@+ZC@,`)&"+`7C)`P`M<`X")6"2`27(,0,M8(X!`_@Y
M?[AW"P"Z6`L`X`&PWR5PRP$M8)D!`_B9?24HK@`D**,`))#-`2V``@+ZCAD`
M`_CK?7AY&0`M6`L")1"R`"4H\0&X?P,`NA@#`"T02P`E>.,!`_BE?"TH10`F
M&,\!,64"/"88;`#K8$)DZ`&LWW@0`@`#^+!\^HX0`"U@@@%X61``+6"-`258
M<0$#^&-\+1AL``/X:WVX9QD`NL@9`"5@F0$M:&L`\`&KWP/XN7TF&.P!^HX9
M``/XSGTF&&4`+5AB`7@I&0`M6&X!)2BQ``/X8WPM&&L``_BE?+A?$`"Z@!``
M)5AP`2TH90#X`:/?`_BP?"9PBP'ZCA``+1AB``/X[WTF<,T!>&D0`"T8;P`#
M^,Y])6BQ`2T8;@`#^*U]N'<9`+K(&0`E<-D!+7AM```"H]\#^/E])FAN`0/X
MD7TM&&(`)F"E`?IN&0!X*1D`+1AQ``/XC'TE**T`+1AL`+AO$``#^*5\NH`0
M`"5HL`$M*&4`"`*CWP/XL'PF8,T!`_AQ?2T88@`F8(\!>%D0`/I^$``M&'$`
M`_B,?258;P$M&&P``_AK?;AG&0"ZR!D`)6"9`2U8:P`0`J/?`_AO?2;(K`$#
M^-%]+1AB`"9P)0/ZS@\`>"D/`"T8<0`#^,Y])2BY`"T8;@`#^*5\N'<0`+J`
M$``E<-`!+2AE`!@"H]\#^+E\)H".`0/XL7TM&&(`)F@+`OJ&&0!X61D`+1AQ
M``/XK7TE6'`!+1AM``/X:WVX;P\`NG@/`"5HKP$M6&L`(`*CWP/X;WTF@,T!
M`_B1?2T88@`F8`4"^H8/`'@I#P`M&'$``_B,?24HL``M&&P``_BE?+AG&0"Z
MR!D`)6"9`2TH90`H`J/?`_BY?":`K`$#^-%]+1AB`"9P"P+ZAAD`>%D9`"T8
M<0`#^,Y])5AP`2T8;@`#^&M]N'</`+IX#P`E<,\!+5AK`#`"H]\#^&]])H".
M`0/XL7TM&&(`)F@%`OJ&#P!X*0\`+1AQ``/XK7TE*+``+1AM``/XI7RX;QD`
MNL@9`"5HN0$M*&4`.`*CWP/XN7PF@,T!`_B1?2T88@`F8`L"^H89`'A9&0`M
M&'$``_B,?258<`$M&&P``_AK?;AG#P"Z>`\`)6"/`2U8:P!``J/?`_AO?2:`
MK`$#^-%]+1AB`"9P!0+ZA@\`>"D/`"T8<0`#^,Y])2BP`"T8;@`#^*5\N'<9
M`+K(&0`E<-D!+2AE`$@"H]\#^+E\)H".`0/XL7TM&&(`)F@+`OJ&&0!X61D`
M+1AQ``/XK7TE6'`!+1AM``/X:WVX;P\`NG@/`"5HKP$M6&L`4`*CWP/X;WTF
M@,T!`_B1?2T88@`F8`4"^H8/`'@I#P`M&'$``_B,?24HL``M&&P``_BE?+AG
M&0"ZR!D`)6"9`2TH90!8`J/?`_BP?";(K`$#^-%]+1AB`"9P*P/ZSA``>%D0
M`"T8<0`#^,Y])5AY`2T8;@`#^&M]N'</`+IX#P`E<,\!+5AK`&`"H]\#^&]]
M)LB.`0/XL7TM&&(`)F@E`_K.#P!X*0\`+1AQ``/XK7TE*+D`+1AM`+C/$``#
M^*5\NH`0`"7(,`,M*&4`:`*CWP/XL7PF:-D!`_B0?2T88@`F8*L!^FX1`'A9
M$0`M&'```_B,?258;0$M&&P``_AK?;AO#P"Z>`\`+6!K`"5HKP%P`J/?`_B0
M?298+0,F6&4!^GX0`"T88@`#^,Y]>"D0`"T8;@`E**\``_AN?2T8;@"X7Q$`
M`_BE?+J($0`E6'$!+7AE`'@"I=\F&*L!`_CN?2THH@`#^#E_)AAL`"THN0`#
M^&-\>,D.`/J.#@`M**,`)1@Q`[AG$``M**,`NH`0`(`"H]\E8)`!+1!B`"88
M;`$#^*5\+1!*``/XK7TF&&\`>%$%`"T030`#^&-\^FX%`"T00P`E&$T!+1!#
M``/X0GRX'PX`NG`.````@OPE&&X`+1AF`(@"JM\M,(<!+2BH`"T0:0$```??
M`_BE?`/X8WP#^,9\`_A"?`@`A?P0`(/\&`"&_`@`1Q4@`(+\N`*_W[`"O-^H
M`K+?H`*QWY@"L-\(`.`#P`*]9UB!F=\)^"`#``````````#P_[UG``"\_P(`
M'#PMX)D#X"6<9VB!F=\(`+__"?@@`X``!"1=3`4\?VZE9'@H!0#G=P8D/0P$
M/!``1?Q%9P<\>#0&`#(0!3P?+H1D`2/G9(FKQF1V5*5D."$$````1_P(`$;\
M&`!%_"``1/PH`$#\,`!`_'@`0*P(`+_?``"\WP@`X`,0`+UGL/^]9T``O/\X
M`+;_&`"R_Q``L?](`+__,`"U_R@`M/\@`+/_"`"P_R@`@]SX$`8`+1!#``(`
M'#P#^$)\+>"9`RL80P`EL,``6"6<9S``AMPED(```@!@$"6(H``!`,9D>A\6
M`'@`1(XM&&8`*`!"_C``0_Y$`(`4.`!09D``PBI7`$`40("5W\#_UB:#R=-^
M`0!T9KBA%``MH#0"H$.U9@<`*6H/`"AJ```I;A<`)VH?`"9J)P`E:B\`)&HW
M`"-J/P`B:@@`*&X0`"=N&``F;B``)6XH`"1N,``C;C@`(FX'``FR```)M@\`
M"+((``BV%P`'LA``![8?``:R&``&MB<`!;(@``6V+P`$LB@`!+8W``.R,``#
MMB4@0`(_``*R)<B@`C@``K;G^1$$0``Q9MO_-!8`````@)D3`".PTP+(@9G?
M)3#``B4H@`()^"`#)2```G@`5JY(`+_?0`"\WS@`MM\P`+7?*`"TWR``L]\8
M`++?$`"QWP@`L-\(`.`#4`"]9P````!``!4D(Q"D`BH8P@(+$,,"R(&9WR4P
M0``E*"`"+2`$`@GX(`,EH$``>`!"CB$05`#G_U44>`!"KD"`E=\E($`"H$.U
M9B7(H`*]^1$$([#4`JC_`!`MB#0"U_\`$"6@(`+`_[UG,`"\_R@`M?\(`+'_
M``"P_S@`O_\@`+3_&`"S_Q``LO\H`++<.`"U9,,H0GX!`$,D`@`</"6`H``M
MX)D#+1"B`B6(@``Y`&4H@/\$)#``$]YP(YQG``!$H'0`H!0M(*,"0``")",0
M0P`$`$,L@P!@$`(`0RQY`&`0`````'4`0!0`````0("4WZ!#E&8ER(`"DOD1
M!"4@``)@@IG?.``&)"4H```)^"`#)2"@`CH>$P``&`,`.B03`"40```'.&)\
M`"`$`#H:$P`'>H)\`!@#``>\8GP`F!,`.AX2``?^8GX`&`,`.B02``8X8GP`
M(`0`.AH2```8`P`&>H)\!KQB?`"0$@`&_D)^)2```B7(@`)R^1$$<``"_@``
M`MXP@IG?.A8"````(J(```+>)2```CH4`@`!`"*B```"WCH2`@`"`"*B```"
MW@,`(J((``+>.A8"``0`(J((``+>.A0"``4`(J((``+>.A("``8`(J((``+>
M!P`BHA```MXZ%@(`"``BHA```MXZ%`(`"0`BHA```MXZ$@(`"@`BHA```MX+
M`"*B&``"WCH6`@`,`"*B&``"WCH4`@`-`"*B&``"WCH2`@`.`"*B&``"W@\`
M(J(@``+>.A8"`!``(J(@``+>.A0"`!$`(J(@``+>.A("`!(`(J(@``+>"?@@
M`Q,`(J(X`+_?,`"\WR@`M=\@`+3?&`"SWQ``LM\(`+'?``"PWP@`X`-``+UG
M`````&""F=\X``8D0("4WR,PPP`E*```"?@@`Z!#E&:9_P`0.AX3``````"+
M_P`0``"`H/[_0F0```````"`H`$`@*"%_T`0`@"$9(/_`!```("@_/]"9`(`
M0RP``("@`0"`H`(`@*`#`("@>?]@%`0`A&3Q_P`0_O]"9```````````\/^]
M9P``O/\"`!P\+>"9`\`@G&<X@(+?@(*9WP``1]P(`+__"?@@`P`````(`+_?
M``"\WP@`X`,0`+UG`````!"`F=\E>.`#"?@@`V4`&&00@)G?)7C@`PGX(`-D
M`!AD$("9WR5XX`,)^"`#8P`89!"`F=\E>.`#"?@@`V(`&&00@)G?)7C@`PGX
M(`-A`!AD$("9WR5XX`,)^"`#8``89!"`F=\E>.`#"?@@`U\`&&00@)G?)7C@
M`PGX(`-<`!AD$("9WR5XX`,)^"`#6P`89!"`F=\E>.`#"?@@`UH`&&00@)G?
M)7C@`PGX(`-9`!AD$("9WR5XX`,)^"`#6``89!"`F=\E>.`#"?@@`U<`&&00
M@)G?)7C@`PGX(`-6`!AD$("9WR5XX`,)^"`#50`89!"`F=\E>.`#"?@@`U0`
M&&00@)G?)7C@`PGX(`-3`!AD$("9WR5XX`,)^"`#40`89!"`F=\E>.`#"?@@
M`U``&&00@)G?)7C@`PGX(`-/`!AD$("9WR5XX`,)^"`#30`89!"`F=\E>.`#
M"?@@`TP`&&00@)G?)7C@`PGX(`-+`!AD$("9WR5XX`,)^"`#2``89!"`F=\E
M>.`#"?@@`T<`&&00@)G?)7C@`PGX(`-&`!AD$("9WR5XX`,)^"`#0P`89!"`
MF=\E>.`#"?@@`T(`&&00@)G?)7C@`PGX(`-!`!AD$("9WR5XX`,)^"`#0``8
M9!"`F=\E>.`#"?@@`S\`&&00@)G?)7C@`PGX(`,]`!AD$("9WR5XX`,)^"`#
M.P`89!"`F=\E>.`#"?@@`SH`&&00@)G?)7C@`PGX(`,Y`!AD$("9WR5XX`,)
M^"`#.``89!"`F=\E>.`#"?@@`S<`&&00@)G?)7C@`PGX(`,V`!AD$("9WR5X
MX`,)^"`#-0`89!"`F=\E>.`#"?@@`S0`&&00@)G?)7C@`PGX(`,S`!AD$("9
MWR5XX`,)^"`#,@`89!"`F=\E>.`#"?@@`S$`&&00@)G?)7C@`PGX(`,P`!AD
M$("9WR5XX`,)^"`#+P`89!"`F=\E>.`#"?@@`RX`&&00@)G?)7C@`PGX(`,M
M`!AD$("9WR5XX`,)^"`#+``89!"`F=\E>.`#"?@@`RL`&&00@)G?)7C@`PGX
M(`,J`!AD$("9WR5XX`,)^"`#*``89!"`F=\E>.`#"?@@`R<`&&00@)G?)7C@
M`PGX(`,F`!AD$("9WR5XX`,)^"`#)0`89!"`F=\E>.`#"?@@`R0`&&00@)G?
M)7C@`PGX(`,C`!AD`````````````````````/#_O6<``+S_`@`</"W@F0,(
M`+__\!R<9P@`O]\``+S?"`#@`Q``O6<```````````$``@``````)7,O)7,`
M```O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I
M+R5S```````N`````````%!!4E]414U0``````````!005)?4%)/1TY!344`
M````.@`````````O`````````"5S)7,E<P``4$523#5,24(``````````%!%
M4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$
M`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'````
M`````%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!0
M05)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````#$`````````3$1?
M3$E"4D%265]0051(`%-94U1%30``+W1M<`````!435!$25(``%1%35!$25(`
M5$5-4`````!435```````%5315(`````55-%4DY!344``````````"4P,G@`
M````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````
M`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S
M92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!0
M051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E
M;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`````````<&5R
M;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4V````
M56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``````````"UE````````+2T```````!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)$-!0TA%7VUA
M<FME<BP@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`]
M(")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C
M:R@B3B(I"B1C86-H95]M87)K97(@/2`B7#!#04-(12(["B1C86-H95]N86UE
M7W-I>F4@/2`T,#L*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]
M($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`D<VEZ92`M("1S:7IE("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["B1P;W,@*ST@)&D["G)E='5R;B`D<&]S.PI]"B1P;W,@
M+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF
M("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T
M;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO
M=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z
M.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN
M:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R
M7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I
M;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD
M)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N
M86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT
M(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R
M7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K
M(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D
M(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O
M;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B
M86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA
M;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF
M(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I
M;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E
M<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?
M<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*
M34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S
M<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A
M;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S
M92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,[
M"GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H
M)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T
M<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D
M;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ
M93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S
M970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P
M.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A
M9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R
M96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K
M:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@
M)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B87-E;F%M
M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN
M(BD["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D
M:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E
M('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D
M:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE
M.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO
M9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*=6YL97-S("@D8G5F(&5Q(")02UPP,#-<,#`T(BD@>PIO=71S*'%Q
M6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R
M;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@
M7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE
M("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N
M)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4
M)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY
M("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-
M4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q
M<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L
M("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B
M=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A
M('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E
M("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/
M7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN
M;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN
M960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PIM>2`D<&%R7V-L96%N(#T@(CTQ
M(CL*;7D@)'!A<W-?<&%R7V-L96%N(#T@=6,@(E]?<&%S<U]P87)?8VQE86Y?
M7R(["B1L;V%D97(@/7X@<WLH/SP])'MP87-S7W!A<E]C;&5A;GTI*"`K*7T*
M>R1P87)?8VQE86X@+B`H(B`B('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'!A
M<E]C;&5A;BDI*7UE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L
M97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@
M)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D
M:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F
M(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN
M+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H
M+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B
M.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N
M86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R
M:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R
M:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL
M"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&
M24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE
M(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["FEF("@A
M)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@
M>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D=&@L
M("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)'1H*3L*8VQO<V4@)'1H
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PHD8V%C:&5?;F%M92`N/2`D8V%C:&5?;6%R:V5R.PIM>2`D;V9F
M<V5T(#T@)&9H+3YT96QL("L@;&5N9W1H*"1C86-H95]N86UE*2`M(&QE;F=T
M:"@D;&]A9&5R*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*<&%C:R@G3B<L
M("1O9F9S970I+`HD4$%27TU!1TE#*0HF)B`D9F@M/F-L;W-E"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI
M"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA
M;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*
M<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M*%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE
M;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E
M($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ
M:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#
M87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S
M971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR
M971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@
M0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM
M>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E
M9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD
M8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@
M(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O
M9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA
M9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,
M15]O9F9S971?<VEZ90HM(&QE;F=T:"@D8V%C:&5?;6%R:V5R*2P@,#L*;7D@
M)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@D8V%C:&5?;6%R:V5R*3L*
M:68@*"1B=68@97$@)&-A8VAE7VUA<FME<BD@>PIS965K("1F:"P@)&UA9VEC
M7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*"1C86-H95]M87)K
M97(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C
M86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`]
M(")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D
M:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B([
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L*
M*&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@
M)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM0
M05)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D
M14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92![
M"B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M
M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES
M>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@
M)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L
M<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-0
M05=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID
M96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@
M0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'
M3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]
M"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y]
M.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H
M*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN
M(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)
M3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W
M*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X
M<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I
M;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R
M.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG
M="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@
M;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G
M;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@
M)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2
M.PHQ.PI?7T5.1%]?"@````!P97)L>'-I+F,`````````+VQI8C8T+VQD+G-O
M+C$`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M.!X```````#('0````````````````````````````#_____````````````
M````*&<`````````````````````````````````````````````````````
M``````"`0!H```````````(``````#@``@``````&`,"````````````````
M`````0``````2#\```````!`)P```````%@H````````D#,```````!06@``
M`````-A:````````P%P```````"H+````````/@T````````:"L```````!P
M7P```````"```@``````($(`````````````````````````````(&,`````
M```08P````````!C````````\&(```````#@8@```````-!B````````````
M``````#`8@```````+!B````````H&(```````"08@```````(!B````````
M<&(```````!@8@```````%!B````````0&(````````P8@```````"!B````
M````$&(`````````8@```````/!A````````X&$```````#080```````,!A
M````````L&$``````````````````*!A``````````````````"080``````
M`(!A````````<&$```````!@80```````%!A````````````````````````
M`````$!A````````,&$````````@80`````````````````````````````0
M80````````!A````````\&```````````````````.!@````````T&``````
M``#`8```````````````````L&````````"@8````````)!@````````@&``
M``````!P8````````&!@````````4&````````!`8````````#!@````````
M(&``````````````````````````````$&``````````8````````/!?````
M````X%\```````#07P```````,!?````````L%\``````````````````!@#
M`@``````1T-#.B`H1&5B:6%N(#$R+C(N,"TS*2`Q,BXR+C````!@'@````!_
MD/C___\``````````%`````=````'P```-@?``````.0^/___P``````````
M``$``!T````?````D"``````'Y#X____```````````@`0``'0```!\```"`
M(@`````?D/C___\``````````%`0```=````'P```+@C`````/^0^/___P``
M````````8````!T````?````8"8``````9#X____```````````@````'0``
M`!\```#H)@``````D/C___\``````````!`````=````'P```$`G``````^0
M^/___P``````````4"```!T````?````0"@`````````````````````````
M````'0```!\```!8*`````#_T/C___\``````````%`1```=````'P```!`K
M``````&0^/___P``````````(````!T````?````:"L`````#Y#X____````
M``````!`$```'0```!\```"H+`````#_T/C___\``````````'`````=````
M'P```)`R``````.0^/___P``````````,````!T````?````2#,``````)#X
M____```````````0````'0```!\```"0,P`````?D/C___\``````````%``
M```=````'P```/@T`````/_0^/___P``````````$((``!T````?````2#\`
M````/Y#X____``````````!0````'0```!\````@0@`````/D/C___\`````
M`````$`````=````'P```$`:`````#^0^/___P``````````<````!T````?
M````H$,`````!Y#X____``````````#``@``'0```!\```!06@``````D/C_
M__\``````````!`````=````'P```-A:`````'^0^/___P``````````4```
M`!T````?````P%P`````/Y#X____``````````!`````'0```!\```!P7P``
M````D/C___\``````````!`````=````'P```$$/````9VYU``$'````!`$`
M+G-H<W1R=&%B`"Y-25!3+F%B:69L86=S`"Y-25!3+F]P=&EO;G,`+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F1Y;F%M:6,`+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M+F1Y;@`N:6YI=``N=&5X=``N34E04RYS='5B<P`N9FEN:0`N<F]D871A`"YI
M;G1E<G``+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A
M`"YR;&1?;6%P`"YG;W0`+G-D871A`"YB<W,`+F-O;6UE;G0`+G!D<@`N9VYU
M+F%T=')I8G5T97,`````````````````````````````````````````````
M````````````````````````````````````````````````"P```"H``'`"
M`````````'`"````````<`(````````8````````````````````"```````
M```8`````````!H````-``!P`@``"`````"(`@```````(@"````````D`$`
M``````````````````@``````````0`````````H````!P````(`````````
M&`0````````8!````````"0````````````````````$````````````````
M````.P````<````"`````````#P$````````/`0````````@````````````
M````````!````````````````````$D````&`````@````````!@!```````
M`&`$````````8`(````````(``````````@`````````$`````````!2````
M!0````(`````````P`8```````#`!@```````"0#````````!P`````````(
M``````````0`````````6`````L````"`````````.@)````````Z`D`````
M``"0"0````````@````"````"``````````8`````````&`````#`````@``
M``````!X$P```````'@3````````N00```````````````````$`````````
M``````````!H````____;P(`````````,A@````````R&````````,P`````
M````!P`````````"``````````(`````````=0```/[__V\"```````````9
M`````````!D```````"@``````````@````"````"```````````````````
M`(0````)`````@````````"@&0```````*`9````````8``````````'````
M``````@`````````$`````````"-`````0````8``````````!H`````````
M&@```````$`````````````````````$````````````````````DP````$`
M```&`````````$`:````````0!H```````!P10``````````````````$```
M`````````````````)D````!````!@````````"P7P```````+!?````````
MD`,```````````````````@```````````````````"E`````0````8`````
M````0&,```````!`8P```````"@````````````````````$````````````
M````````JP````$````"`````````'!C````````<&,```````#`00``````
M````````````$````````````````````+,````!`````@`````````PI0``
M`````#"E````````#P````````````````````$```````````````````"[
M`````0````(`````````0*4```````!`I0````````0`````````````````
M```$````````````````````Q0````X````#`````````/#_`0``````\/\`
M```````(````````````````````"``````````(`````````-$````/````
M`P````````#X_P$``````/C_````````"`````````````````````@`````
M````"`````````#=`````0````,````````````"``````````$``````#``
M```````````````````0````````````````````XP````$````#````````
M`#```@``````,``!```````(````````````````````"```````````````
M`````.P````!`````P``$`````!```(``````$```0``````V`(`````````
M`````````!``````````"`````````#Q`````0````,``!``````&`,"````
M```8`P$```````@````````````````````(````````````````````^```
M``@````#`````````"`#`@``````(`,!```````P````````````````````
M$````````````````````/T````!````,````````````````````"`#`0``
M````'@````````````````````$``````````0`````````&`0```0``````
M``````````````````!``P$``````"`#```````````````````$````````
M````````````"P$``/7__V\`````````````````````8`8!```````0````
M`````````````````0````````````````````$````#````````````````
M`````````'`&`0``````&P$```````````````````$`````````````````
"````
